@@ -4,7 +4,7 @@
 - ``NestedSamples``
 """
 import os
-import numpy
+import numpy as np
 import pandas
 from anesthetic.plot import (make_1d_axes, make_2d_axes, fastkde_plot_1d,
                              kde_plot_1d, hist_plot_1d, scatter_plot_2d,
@@ -32,16 +32,16 @@ class MCMCSamples(WeightedDataFrame):
     root: str, optional
         root for reading chains from file. Overrides all other arguments.
 
-    data: numpy.array
+    data: np.array
         Coordinates of samples. shape = (nsamples, ndims).
 
     columns: list(str)
         reference names of parameters
 
-    w: numpy.array
+    w: np.array
         weights of samples.
 
-    logL: numpy.array
+    logL: np.array
         loglikelihoods of samples.
 
     tex: dict
@@ -55,7 +55,7 @@ class MCMCSamples(WeightedDataFrame):
 
     logzero: float
         The threshold for `log(0)` values assigned to rejected sample points.
-        Anything equal or below this value is set to `-numpy.inf`.
+        Anything equal or below this value is set to `-np.inf`.
         default: -1e30
 
     """
@@ -82,7 +82,7 @@ class MCMCSamples(WeightedDataFrame):
             logzero = kwargs.pop('logzero', -1e30)
             logL = kwargs.pop('logL', None)
             if logL is not None:
-                logL = numpy.where(logL <= logzero, -numpy.inf, logL)
+                logL = np.where(logL <= logzero, -np.inf, logL)
             self.tex = kwargs.pop('tex', {})
             self.limits = kwargs.pop('limits', {})
             self.label = kwargs.pop('label', None)
@@ -380,16 +380,16 @@ class NestedSamples(MCMCSamples):
     root: str, optional
         root for reading chains from file. Overrides all other arguments.
 
-    data: numpy.array
+    data: np.array
         Coordinates of samples. shape = (nsamples, ndims).
 
     columns: list(str)
         reference names of parameters
 
-    logL: numpy.array
+    logL: np.array
         loglikelihoods of samples.
 
-    logL_birth: numpy.array or int
+    logL_birth: np.array or int
         birth loglikelihoods, or number of live points.
 
     tex: dict
@@ -406,7 +406,7 @@ class NestedSamples(MCMCSamples):
 
     logzero: float
         The threshold for `log(0)` values assigned to rejected sample points.
-        Anything equal or below this value is set to `-numpy.inf`.
+        Anything equal or below this value is set to `-np.inf`.
         default: -1e30
 
     """
@@ -429,8 +429,8 @@ class NestedSamples(MCMCSamples):
             self._beta = kwargs.pop('beta', 1.)
             logL_birth = kwargs.pop('logL_birth', None)
             if not isinstance(logL_birth, int) and logL_birth is not None:
-                logL_birth = numpy.where(logL_birth <= logzero,
-                                         -numpy.inf, logL_birth)
+                logL_birth = np.where(logL_birth <= logzero, -np.inf,
+                                      logL_birth)
 
             super(NestedSamples, self).__init__(logzero=logzero,
                                                 *args, **kwargs)
@@ -447,8 +447,9 @@ class NestedSamples(MCMCSamples):
     @beta.setter
     def beta(self, beta):
         self._beta = beta
-        logw = self.dlogX() + self.beta*self.logL
-        self._weight = numpy.exp(logw - logw.max())
+        logw = self.dlogX() + np.where(self.logL == -np.inf, -np.inf,
+                                       self.beta * self.logL)
+        self._weight = np.exp(logw - logw.max())
 
         if self._weight is not None:
             self['weight'] = self.weight
@@ -501,8 +502,8 @@ class NestedSamples(MCMCSamples):
         logw -= samples.logZ
         S = (dlogX*0).add(self.beta * self.logL, axis=0) - samples.logZ
 
-        samples['D'] = numpy.exp(logsumexp(logw, b=S, axis=0))
-        samples['d'] = numpy.exp(logsumexp(logw, b=(S-samples.D)**2, axis=0))*2
+        samples['D'] = np.exp(logsumexp(logw, b=S, axis=0))
+        samples['d'] = np.exp(logsumexp(logw, b=(S-samples.D)**2, axis=0))*2
 
         samples.tex = {'logZ': r'$\log\mathcal{Z}$',
                        'D': r'$\mathcal{D}$',
@@ -534,7 +535,7 @@ class NestedSamples(MCMCSamples):
         logZ = self.logZ(dlogX)
         logw = dlogX.add(self.beta * self.logL, axis=0) - logZ
         S = (dlogX*0).add(self.beta * self.logL, axis=0) - logZ
-        return numpy.exp(logsumexp(logw, b=S, axis=0))
+        return np.exp(logsumexp(logw, b=S, axis=0))
 
     def d(self, nsamples=None):
         """Bayesian model dimensionality.
@@ -549,7 +550,7 @@ class NestedSamples(MCMCSamples):
         D = self.D(dlogX)
         logw = dlogX.add(self.beta * self.logL, axis=0) - logZ
         S = (dlogX*0).add(self.beta * self.logL, axis=0) - logZ
-        return numpy.exp(logsumexp(logw, b=(S-D)**2, axis=0))*2
+        return np.exp(logsumexp(logw, b=(S-D)**2, axis=0))*2
 
     def live_points(self, logL=None):
         """Get the live points within logL.
@@ -594,24 +595,24 @@ class NestedSamples(MCMCSamples):
             distribution. (Default: None)
 
         """
-        with numpy.errstate(divide='ignore'):
-            if numpy.ndim(nsamples) > 0:
+        with np.errstate(divide='ignore'):
+            if np.ndim(nsamples) > 0:
                 return nsamples
             elif nsamples is None:
-                t = numpy.log(self.nlive/(self.nlive+1)).to_frame()
+                t = np.log(self.nlive/(self.nlive+1)).to_frame()
             else:
-                r = numpy.log(numpy.random.rand(len(self), nsamples))
+                r = np.log(np.random.rand(len(self), nsamples))
                 t = pandas.DataFrame(r, self.index).divide(self.nlive, axis=0)
 
         logX = t.cumsum()
         logXp = logX.shift(1, fill_value=0)
-        logXm = logX.shift(-1, fill_value=-numpy.inf)
+        logXm = logX.shift(-1, fill_value=-np.inf)
         dlogX = logsumexp([logXp.values, logXm.values],
-                          b=[numpy.ones_like(logXp), -numpy.ones_like(logXm)],
-                          axis=0) - numpy.log(2)
+                          b=[np.ones_like(logXp), -np.ones_like(logXm)],
+                          axis=0) - np.log(2)
 
         if nsamples is None:
-            dlogX = numpy.squeeze(dlogX)
+            dlogX = np.squeeze(dlogX)
             return WeightedSeries(dlogX, self.index, w=self.weight)
         else:
             return WeightedDataFrame(dlogX, self.index, w=self.weight)
@@ -620,7 +621,7 @@ class NestedSamples(MCMCSamples):
         if is_int(logL_birth):
             nlive = logL_birth
             self['nlive'] = nlive
-            descending = numpy.arange(nlive, 0, -1)
+            descending = np.arange(nlive, 0, -1)
             self.loc[len(self)-nlive:, 'nlive'] = descending
         else:
             self['logL_birth'] = logL_birth
